<?php

namespace App\Http\Controllers\api;

use App\Models\User;
use App\Models\BMIRange;
use App\Models\ProgramMeal;
use App\Models\CustomerPlan;
use Illuminate\Http\Request;
use App\Models\CustomerAnswer;
use App\Models\ProgramExercise;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;

class CustomerAnswerController extends Controller
{
    public function store(Request $request)
    {
        // return $request->all();
        // Assuming you have extracted the data from the request.
        $fitnessCategoryId = $request->input('fitness_category_id');
        $gender = $request->input('gender');
        $bmi = $request->input('bmi');
        $exerciseType = $request->input('exercise_type');

        // Find the corresponding BMI range based on the BMI value.
        // You will need to implement the logic to find the range.
        $bmIRange = BMIRange::where('bmi_from', '<=', $bmi)
            ->where('bmi_to', '>=', $bmi)
            ->first();

        // Check if a BMI range was found.
        if (!$bmIRange) {
            return response()->json(['error' => 'No matching BMI range found for the given BMI value.'], 404);
        }

        // Filter exercises based on the criteria in the request and exclude exercises from other BMI ranges.
        $filteredExercises = ProgramExercise::where('fitness_category_id', $fitnessCategoryId)
            ->where('gender', $gender)
            ->where('exercise_type', $exerciseType)
            ->whereHas('bmi_range_exercises', function ($query) use ($bmIRange) {
                $query->where('bmi_range_id', $bmIRange->id);
            })
            ->whereDoesntHave('bmi_range_exercises', function ($query) use ($bmIRange) {
                $query->where('bmi_range_id', '!=', $bmIRange->id);
            })
            ->get();

        // Filter meals based on the criteria in the request and exclude meals from other BMI ranges.
        $filteredMeals = ProgramMeal::where('gender', $gender)
            ->whereHas('bmi_range_meals', function ($query) use ($bmIRange) {
                $query->where('bmi_range_id', $bmIRange->id);
            })
            ->whereDoesntHave('bmi_range_meals', function ($query) use ($bmIRange) {
                $query->where('bmi_range_id', '!=', $bmIRange->id);
            })
            ->get();
        if ($filteredExercises->isEmpty() && $filteredMeals->isEmpty()) {
            return response()->json([
                'success' => false,
                'message' => 'No exercises found for the given criteria.',
                'data' => [],
            ]);
        }

        $weeks = [];

        // Create four weeks of exercises.
        for ($week = 1; $week <= 12; $week++) {
            $weekKey = "Week $week";
            $weekData = [
                'week' => $weekKey,
                'days' => [],
            ];

            $daysOfWeek = ['Day 1', 'Day 2', 'Day 3', 'Day 4', 'Day 5', 'Day 6', 'Day 7'];

            foreach ($daysOfWeek as $dayOfWeek) {
                $dayData = [
                    'day' => $dayOfWeek,
                    'exercises' => [],
                    'meals' => [],
                ];

                foreach ($filteredExercises as $index => $exercise) {
                    $exerciseDayOfWeek = $daysOfWeek[$index % 6]; // Cycle through Day 1, Day 2, ..., Day 7

                    if ($exerciseDayOfWeek === $dayOfWeek) {
                        $exerciseData = [
                            'id' => $exercise->id,
                            'fitness_category_id' => $exercise->fitness_category_id,
                            'gender' => $exercise->gender,
                            'exercise_type' => $exercise->exercise_type,
                            'exercise_name' => $exercise->exercise_name,
                            'description' => $exercise->description,
                            'animation' => $exercise->animation,
                            'focus_points' => $exercise->focus_points,
                            'created_at' => $exercise->created_at,
                            'updated_at' => $exercise->updated_at,
                        ];

                        // Decode JSON strings for sets, reps, and rest
                        $setsData = json_decode($exercise->sets, true);
                        $repsData = json_decode($exercise->reps, true);
                        $restData = json_decode($exercise->rest, true);

                        // Extract values for month 1
                        $setsMonth1 = isset($setsData['month1']) ? (int)$setsData['month1'] : 0;
                        $repsMonth1 = isset($repsData['month1']) ? (int)$repsData['month1'] : 0;
                        $restMonth1 = isset($restData['month1']) ? (int)$restData['month1'] : 0;

                        // Extract values for month 2
                        $setsMonth2 = isset($setsData['month2']) ? (int)$setsData['month2'] : 0;
                        $repsMonth2 = isset($repsData['month2']) ? (int)$repsData['month2'] : 0;
                        $restMonth2 = isset($restData['month2']) ? (int)$restData['month2'] : 0;

                        // Extract values for month 3
                        $setsMonth3 = isset($setsData['month3']) ? (int)$setsData['month3'] : 0;
                        $repsMonth3 = isset($repsData['month3']) ? (int)$repsData['month3'] : 0;
                        $restMonth3 = isset($restData['month3']) ? (int)$restData['month3'] : 0;

                        // if current week is less than or equal to 4, use month 1 values
                        if ($week <= 4) {
                            $exerciseData['sets'] = $setsMonth1;
                            $exerciseData['reps'] = $repsMonth1;
                            $exerciseData['rest'] = $restMonth1;
                        }

                        // if current week is greater than 4 and less than or equal to 8, use month 2 values
                        if ($week > 4 && $week <= 8) {
                            $exerciseData['sets'] = $setsMonth2;
                            $exerciseData['reps'] = $repsMonth2;
                            $exerciseData['rest'] = $restMonth2;
                        }

                        // if current week is greater than 8 and less than or equal to 12, use month 3 values
                        if ($week > 8 && $week <= 12) {
                            $exerciseData['sets'] = $setsMonth3;
                            $exerciseData['reps'] = $repsMonth3;
                            $exerciseData['rest'] = $restMonth3;
                        }

                        $dayData['exercises'][] = $exerciseData;
                    }
                }

                // Add meals to the dayData array
                foreach ($filteredMeals as $meal) {
                    // You can customize the meal data structure as needed
                    $mealData = [
                        'id' => $meal->id,
                        'gender' => $meal->gender,
                        'meal_name' => $meal->meal_name,
                        'calories' => $meal->calories,
                        'protein' => $meal->protein,
                        'carbs' => $meal->carbs,
                        'fats' => $meal->fats,
                        'created_at' => $meal->created_at,
                        'updated_at' => $meal->updated_at,
                    ];

                    $dayData['meals'][] = $mealData;
                }

                $weekData['days'][] = $dayData;
            }

            $weeks[] = $weekData;
        }

        return response()->json([
            'success' => true,
            'message' => 'Plans generated successfully.',
            'data' => $weeks,
        ]);
    }
}
