<?php

namespace App\Http\Controllers;

use App\Models\QuestionType;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class QuestionTypeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $question_types = QuestionType::all();
        return view('admin.question_type.index', compact('question_types'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|unique:question_types,name|max:255',
        ]);

        if ($validator->fails()) {
            return redirect()->route('question-type.index')
                ->withErrors($validator)
                ->withInput();
        } else {
            $question_type = QuestionType::create($request->all());
            return redirect()->route('question-type.index')->with('success', 'Question type created successfully');
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $question_type = QuestionType::find($id);
        return view('admin.question_type.edit', compact('question_type'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string|unique:question_types,name,' . $id . '|max:255',
        ]);

        if ($validator->fails()) {
            return redirect()->route('question-type.edit', $id)
                ->withErrors($validator)
                ->withInput();
        } else {
            $question_type = QuestionType::find($id);
            $question_type->update($request->all());
            return redirect()->route('question-type.index')->with('success', 'Question Type updated successfully');
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        $question_type = QuestionType::find($id);
        $question_type->delete();
        return redirect()->route('question-type.index')->with('success', 'Question Type deleted successfully');
    }
}
