@extends('admin.layout.layout')
@section('content')
    <div class="card">
        <div class="card-body">
            <div class="row mb-3">
                <div class="col">
                    <h4 class="card-title">Questions</h4>
                </div>
                <div class="col text-end">
                    <button type="button" class="btn btn-primary text-white" data-bs-toggle="modal"
                        data-bs-target="#addQuestionModal">Add Question</button>
                </div>
            </div>
            <div class="table-responsive">
                <table class="table table-striped" id="myTable">
                    <thead>
                        <tr>
                            <th>S.NO</th>
                            <th>Question Type</th>
                            <th>Question</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($questions as $question)
                            <tr>
                                <td>{{ $loop->iteration }}</td>
                                <td>{{ $question->question_type->name }}</td>
                                <td>{{ $question->question }}</td>
                                <td>
                                    <div class="dropdown">
                                        <button class="btn btn-primary text-white dropdown-toggle dropdown-toggle-no-arrow"
                                            type="button" id="dropdownMenuButton1" data-bs-toggle="dropdown"
                                            aria-expanded="false">
                                            <i class="bi bi-three-dots"></i>
                                        </button>

                                        <ul class="dropdown-menu" aria-labelledby="dropdownMenuButton1">
                                            <li>
                                                <a class="dropdown-item" href="{{ route('question.edit', $question->id) }}">
                                                    Edit
                                                </a>
                                            </li>
                                            <li>
                                                <a class="dropdown-item"
                                                    href="{{ route('question.destroy', $question->id) }}"
                                                    onclick="event.preventDefault();
                                                        swal({
                                                            title: 'Are you sure?',
                                                            text: 'Once deleted, you will not be able to recover this question!',
                                                            icon: 'warning',
                                                            buttons: true,
                                                            dangerMode: true,
                                                        }).then((willDelete) => {
                                                            if (willDelete) {
                                                                document.getElementById('delete-form-{{ $question->id }}').submit();
                                                            }
                                                        });">Delete
                                                </a>
                                                <form id="delete-form-{{ $question->id }}"
                                                    action="{{ route('question.destroy', $question->id) }}" method="POST"
                                                    style="display: none;">
                                                    @csrf
                                                    @method('DELETE')
                                                </form>
                                            </li>
                                        </ul>
                                    </div>
                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
    {{-- Data Table Code --}}
    <script>
        let table = new DataTable('#myTable');
    </script>
    {{-- Opening modal if any error exists --}}
    @if ($errors->any())
        <script>
            $(document).ready(function() {
                $('#addQuestionModal').modal('show');
            });
        </script>
    @endif
    <!-- Modal -->
    <div class="modal fade" id="addQuestionModal" tabindex="-1" aria-labelledby="addQuestionModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addQuestionModalLabel">Add Question</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <div class="card">
                        <div class="card-body">
                            <form class="forms-sample" method="POST" action="{{ route('question.store') }}">
                                @csrf
                                <div class="form-group pt-3">
                                    <label for="fitness_category_id">Fitness Category</label>
                                    <div>
                                        @foreach ($fitness_categories as $fitness_category)
                                            <div class="form-check form-check-inline">
                                                <input class="form-check-input ms-1 @error('fitness_category_id') is-invalid @enderror" type="checkbox" name="fitness_category_id[]" id="fitness_category_{{ $fitness_category->id }}" value="{{ $fitness_category->id }}" @if(is_array(old('fitness_category_id')) && in_array($fitness_category->id, old('fitness_category_id'))) checked @endif required>
                                                <label class="form-check-label" for="fitness_category_{{ $fitness_category->id }}">
                                                    {{ $fitness_category->name }}
                                                </label>
                                            </div>
                                        @endforeach
                                        @error('fitness_category_id')
                                            <div class="invalid-feedback">{{ $message }}</div>
                                        @enderror
                                    </div>
                                </div>

                                <div class="form-group pt-3">
                                    <label for="question_type_id">Question Type</label>
                                    <select class="form-control @error('question_type_id') is-invalid @enderror" id="question_type_id" name="question_type_id" required>
                                        <option value="">Select Question Type</option>
                                        @foreach ($question_types as $question_type)
                                            <option value="{{ $question_type->id }}" @if(old('question_type_id') == $question_type->id) selected @endif>{{ $question_type->name }}</option>
                                        @endforeach
                                    </select>
                                    @error('question_type_id')
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>

                                <div class="form-group pt-3">
                                    <label>Question</label>
                                    <input type="text" class="form-control @error('question') is-invalid @enderror"
                                        name="question" id="question" placeholder="Enter question"
                                        value="{{ old('question') }}" required>
                                    @error('question')
                                        <div class="invalid-feedback">{{ $message }}</div>
                                    @enderror
                                </div>
                                <button type="submit" class="btn btn-primary me-2 text-white">Submit</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>


    <script>
        const checkboxes = document.querySelectorAll('input[type=checkbox][name="fitness_category_id[]"]');

        const setCheckboxRequired = () => {
            const checked = Array.from(checkboxes).some((c) => c.checked);
            checkboxes.forEach((c) => c.required = !checked);
        }

        checkboxes.forEach((checkbox) => {
            checkbox.addEventListener('click', setCheckboxRequired);
        });

        // set checkbox required initially if no checkbox is checked
        setCheckboxRequired();
    </script>


@endsection
